# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.7
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from static_server_connector.models.design_switches import DesignSwitches  # noqa: E501

class TestDesignSwitches(unittest.TestCase):
    """DesignSwitches unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DesignSwitches:
        """Test DesignSwitches
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DesignSwitches`
        """
        model = DesignSwitches()  # noqa: E501
        if include_optional:
            return DesignSwitches(
                domain = '',
                use_new_design = True
            )
        else:
            return DesignSwitches(
                domain = '',
                use_new_design = True,
        )
        """

    def testDesignSwitches(self):
        """Test DesignSwitches"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.7
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class PagePublish(BaseModel):
    """
    PagePublish
    """
    portal_urls: conlist(StrictStr) = Field(...)
    id: StrictInt = Field(...)
    title: StrictStr = Field(...)
    favicon_url: Optional[StrictStr] = None
    path: StrictStr = Field(...)
    html: StrictStr = Field(...)
    css: StrictStr = Field(...)
    js: StrictStr = Field(...)
    editor_version: StrictInt = Field(...)
    noindex: Optional[StrictBool] = None
    __properties = ["portal_urls", "id", "title", "favicon_url", "path", "html", "css", "js", "editor_version", "noindex"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PagePublish:
        """Create an instance of PagePublish from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PagePublish:
        """Create an instance of PagePublish from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PagePublish.parse_obj(obj)

        _obj = PagePublish.parse_obj({
            "portal_urls": obj.get("portal_urls"),
            "id": obj.get("id"),
            "title": obj.get("title"),
            "favicon_url": obj.get("favicon_url"),
            "path": obj.get("path"),
            "html": obj.get("html"),
            "css": obj.get("css"),
            "js": obj.get("js"),
            "editor_version": obj.get("editor_version"),
            "noindex": obj.get("noindex")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.7
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist
from static_server_connector.models.domain_new import DomainNew
from static_server_connector.models.domain_switch import DomainSwitch

class DomainMigrate(BaseModel):
    """
    DomainMigrate
    """
    domain_switches: conlist(DomainSwitch) = Field(...)
    new_domains: conlist(DomainNew) = Field(...)
    remove_domains: conlist(StrictStr) = Field(...)
    __properties = ["domain_switches", "new_domains", "remove_domains"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DomainMigrate:
        """Create an instance of DomainMigrate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in domain_switches (list)
        _items = []
        if self.domain_switches:
            for _item in self.domain_switches:
                if _item:
                    _items.append(_item.to_dict())
            _dict['domain_switches'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in new_domains (list)
        _items = []
        if self.new_domains:
            for _item in self.new_domains:
                if _item:
                    _items.append(_item.to_dict())
            _dict['new_domains'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DomainMigrate:
        """Create an instance of DomainMigrate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DomainMigrate.parse_obj(obj)

        _obj = DomainMigrate.parse_obj({
            "domain_switches": [DomainSwitch.from_dict(_item) for _item in obj.get("domain_switches")] if obj.get("domain_switches") is not None else None,
            "new_domains": [DomainNew.from_dict(_item) for _item in obj.get("new_domains")] if obj.get("new_domains") is not None else None,
            "remove_domains": obj.get("remove_domains")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.7
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from static_server_connector.models.page_publish import PagePublish  # noqa: E501

class TestPagePublish(unittest.TestCase):
    """PagePublish unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PagePublish:
        """Test PagePublish
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PagePublish`
        """
        model = PagePublish()  # noqa: E501
        if include_optional:
            return PagePublish(
                portal_urls = [
                    ''
                    ],
                id = 56,
                title = '',
                favicon_url = '',
                path = '',
                html = '',
                css = '',
                js = '',
                editor_version = 56,
                noindex = True
            )
        else:
            return PagePublish(
                portal_urls = [
                    ''
                    ],
                id = 56,
                title = '',
                path = '',
                html = '',
                css = '',
                js = '',
                editor_version = 56,
        )
        """

    def testPagePublish(self):
        """Test PagePublish"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
